/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

(function ($) {

    // Site title and description.
    wp.customize('blogname', function (value) {
        value.bind(function (to) {
            $('.site-title a').text(to);
        });
    });
    wp.customize('blogdescription', function (value) {
        value.bind(function (to) {
            $('.site-description').text(to);
        });
    });

    /* CONTAINERS */
    // Container: SM
    wp.customize('container-max-width-sm', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--container-max-width-sm', to + 'px');
            }
        });
    });
    // Container: MD
    wp.customize('container-max-width-md', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--container-max-width-md', to + 'px');
            }
        });
    });
    // Container: LG
    wp.customize('container-max-width-lg', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--container-max-width-lg', to + 'px');
            }
        });
    });
    // Container: XL
    wp.customize('container-max-width-xl', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--container-max-width-xl', to + 'px');
            }
        });
    });
    // Container: XXL
    wp.customize('container-max-width-xxl', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--container-max-width-xxl', to + 'px');
            }
        });
    });

    // Mobile Navigation
    wp.customize('mobile-navigation-width', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--mobile-navigation-width', to + '%');
            }
        });
    });

    // Site Content - Before Header and Before Footer
    wp.customize('ysp-before-header-content', function (value) {
        value.bind(function (to) {
            $('.site-global-content-start').text(to);
        });
    });
    wp.customize('ysp-after-header-content', function (value) {
        value.bind(function (to) {
            $('.site-global-after-header').text(to);
        });
    });
    wp.customize('ysp-header-content-start', function (value) {
        value.bind(function (to) {
            $('.site-global-header-start').text(to);
        });
    });
    wp.customize('ysp-before-main-content', function (value) {
        value.bind(function (to) {
            $('.site-global-main-content-start').text(to);
        });
    });
    wp.customize('ysp-after-main-content', function (value) {
        value.bind(function (to) {
            $('.site-global-main-content-end').text(to);
        });
    });
    wp.customize('ysp-before-footer-content', function (value) {
        value.bind(function (to) {
            $('.site-global-content-end').text(to);
        });
    });

    // Header text color.
    wp.customize('header_textcolor', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {
                $('.site-title, .site-description').css({
                    'clip': 'rect(1px, 1px, 1px, 1px)',
                    'position': 'absolute'
                });
            } else {
                $('.site-title, .site-description').css({
                    'clip': 'auto',
                    'position': 'relative'
                });
                $('.site-title a, .site-description').css({
                    'color': to
                });
            }
        });
    });

    /* COLORS */
    // Body Color
    wp.customize('body-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--body-color', to);
            }
        });
    });
    // Text Color
    wp.customize('text-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--text-color', to);
            }
        });
    });
    wp.customize('text-color-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--text-color-hover', to);
            }
        });
    });
    // Link Color
    wp.customize('link-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--link-color', to);
            }
        });
    });
    wp.customize('link-color-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--link-color-hover', to);
            }
        });
    });
    // Color Default
    wp.customize('color-default', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-default', to);
            }
        });
    });
    wp.customize('color-default-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-default-hover', to);
            }
        });
    });
    // Color 1
    wp.customize('color-1', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-1', to);
            }
        });
    });
    wp.customize('color-1-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-1-hover', to);
            }
        });
    });
    // Color 2
    wp.customize('color-2', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-2', to);
            }
        });
    });
    wp.customize('color-2-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-2-hover', to);
            }
        });
    });
    // Color 3
    wp.customize('color-3', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-3', to);
            }
        });
    });
    wp.customize('color-3-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-3-hover', to);
            }
        });
    });
    // Color 4
    wp.customize('color-4', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-4', to);
            }
        });
    });
    wp.customize('color-4-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-4-hover', to);
            }
        });
    });
    // Color 5
    wp.customize('color-5', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-5', to);
            }
        });
    });
    wp.customize('color-5-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-5-hover', to);
            }
        });
    });
    // Color 6
    wp.customize('color-6', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-6', to);
            }
        });
    });
    wp.customize('color-6-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-6-hover', to);
            }
        });
    });
    // Color 7
    wp.customize('color-7', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-7', to);
            }
        });
    });
    wp.customize('color-7-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-7-hover', to);
            }
        });
    });
    // Color 8
    wp.customize('color-8', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-8', to);
            }
        });
    });
    wp.customize('color-8-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-8-hover', to);
            }
        });
    });
    // Color 9
    wp.customize('color-9', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-9', to);
            }
        });
    });
    wp.customize('color-9-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-9-hover', to);
            }
        });
    });
    // Color 10
    wp.customize('color-0', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-0', to);
            }
        });
    });
    wp.customize('color-0-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--color-0-hover', to);
            }
        });
    });

    // Grays
    wp.customize('gray-1', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--gray-1', to);
            }
        });
    });
    wp.customize('gray-2', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--gray-2', to);
            }
        });
    });
    wp.customize('gray-3', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--gray-3', to);
            }
        });
    });
    wp.customize('gray-4', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--gray-4', to);
            }
        });
    });
    wp.customize('gray-5', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--gray-5', to);
            }
        });
    });
    // Start - Top Header (Addon)
    wp.customize('top-header-background-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--top-header-background-color', to);
            }
        });
    });
    // End - Top Header (Addon)
    wp.customize('header-background-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--header-background-color', to);
            }
        });
    });
    wp.customize('header-text-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--header-text-color', to);
            }
        });
    });
    wp.customize('header-text-color-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--header-text-color-hover', to);
            }
        });
    });
    // Start - Navigation (Addon)
    wp.customize('hang-nav-background-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--hang-nav-background-color', to);
            }
        });
    });
    wp.customize('hang-nav-text-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--hang-nav-text-color', to);
            }
        });
    });
    wp.customize('hang-nav-text-color-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--hang-nav-text-color-hover', to);
            }
        });
    });
    wp.customize('mega-menu-background-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--mega-menu-background-color', to);
            }
        });
    });
    wp.customize('mega-menu-title-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--mega-menu-title-color', to);
            }
        });
    });
    wp.customize('mega-menu-title-color-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--mega-menu-title-color-hover', to);
            }
        });
    });
    wp.customize('mega-menu-text-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--mega-menu-text-color', to);
            }
        });
    });
    wp.customize('mega-menu-text-color-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--mega-menu-text-color-hover', to);
            }
        });
    });
    // End - Navigation (Addon)
    wp.customize('footer-background-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-background-color', to);
            }
        });
    });
    wp.customize('footer-title-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-title-color', to);
            }
        });
    });
    wp.customize('footer-text-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-text-color', to);
            }
        });
    });
    wp.customize('footer-link-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-link-color', to);
            }
        });
    });
    wp.customize('footer-link-color-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-link-color-hover', to);
            }
        });
    });
    wp.customize('footer-bottom-background-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-bottom-background-color', to);
            }
        });
    });
    wp.customize('footer-bottom-text-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-bottom-text-color', to);
            }
        });
    });
    wp.customize('footer-bottom-link-color', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-bottom-link-color', to);
            }
        });
    });
    wp.customize('footer-bottom-link-color-hover', function (value) {
        value.bind(function (to) {
            if ('blank' === to) {} else {
                document.documentElement.style.setProperty('--footer-bottom-link-color-hover', to);
            }
        });
    });

})(jQuery);