export const main_mobile_nav_core = $ => {
    (function ($) {
        "use strict";

        /**
         * Extend Object helper function.
         */
        function extend(a, b) {
            for (var key in b) {
                if (b.hasOwnProperty(key)) {
                    a[key] = b[key];
                }
            }
            return a;
        }

        /**
         * Each helper function.
         */
        function each(collection, callback) {
            for (var i = 0; i < collection.length; i++) {
                var item = collection[i];
                callback(item);
            }
        }

        /**
         * Menu Constructor.
         */
        function Menu(options) {
            this.options = extend({}, this.options);
            extend(this.options, options);
            this._init();
        }

        /**
         * Menu Options.
         */
        Menu.prototype.options = {
            wrapper: "#page", // The content wrapper
            type: "mobile-left", // The menu type
            menuOpenerClass: ".c-mobile-nav-toggler", // The menu opener class names (i.e. the buttons)
            maskId: "#c-mobile-nav-mask" // The ID of the mask
        };

        /**
         * Initialise Menu.
         */
        Menu.prototype._init = function () {
            this.body = document.body;
            this.wrapper = document.querySelector(this.options.wrapper);
            this.mask = document.querySelector(this.options.maskId);
            this.menu = document.querySelector("#c-mobile-nav--" + this.options.type);
            this.closeBtn = this.menu.querySelector(".c-mobile-nav__close");
            this.toggleBtn = document.querySelector(".c-mobile-nav__toggle");
            this.toggleBtnEls = document.getElementsByClassName("c-mobile-nav__toggle");
            this.menuOpeners = document.querySelectorAll(
                this.options.menuOpenerClass
            );
            this._initEvents();
        };

        /**
         * Initialise Menu Events.
         */
        Menu.prototype._initEvents = function () {
            // Event for clicks on the close button inside the menu.
            this.closeBtn.addEventListener("click", function (e) {
                e.preventDefault();
                this.close();
            }.bind(this));

            // Event for clicks on the close button inside the menu.
            this.toggleBtn.addEventListener("click", function (e) {
                e.preventDefault();
                if (this.toggleBtn.classList.contains("c-mobile-nav__toggle-close")) {
                    this.close();
                } else {
                    this.open();
                    each(this.toggleBtnEls, function (item) {
                        item.classList.add("c-mobile-nav__toggle-close");
                    });
                }
            }.bind(this));

            // Event for clicks on the mask.
            this.mask.addEventListener("click", function (e) {
                e.preventDefault();
                this.close();
            }.bind(this));
        };

        /**
         * Open Menu.
         */
        Menu.prototype.open = function () {
            this.body.classList.add("has-active-menu");
            this.wrapper.classList.add("has-" + this.options.type);
            this.menu.classList.add("is-active");
            this.mask.classList.add("is-active");
            // this.disableMenuOpeners();
        };

        /**
         * Close Menu.
         */
        Menu.prototype.close = function () {
            this.body.classList.remove("has-active-menu");
            this.wrapper.classList.remove("has-" + this.options.type);
            this.menu.classList.remove("is-active");
            this.mask.classList.remove("is-active");
            // this.enableMenuOpeners();
            each(document.getElementsByClassName("c-mobile-nav__toggle-close"), function (item) {
                item.classList.remove("c-mobile-nav__toggle-close");
            });
        };

        /**
         * Disable Menu Openers.
         */
        // Menu.prototype.disableMenuOpeners = function () {
        //     each(this.menuOpeners, function (item) {
        //         item.disabled = true;
        //     });
        // };

        /**
         * Enable Menu Openers.
         */
        // Menu.prototype.enableMenuOpeners = function () {
        //     each(this.menuOpeners, function (item) {
        //         item.disabled = false;
        //     });
        // };

        /**
         * Add to global namespace.
         */

        window.Menu = Menu;
    })(window);
};