// https://dev.to/pixelgoo/how-to-configure-webpack-from-scratch-for-a-basic-website-46a5
// https://carrieforde.com/webpack-wordpress/
const path = require("path"),
    MiniCssExtractPlugin = require("mini-css-extract-plugin"),
    FileManagerPlugin = require("filemanager-webpack-plugin");

module.exports = [{
        name: "main",
        // Path to your entry point. From this file Webpack will begin his work
        entry: ["./assets/src/js/main.js", "./assets/src/scss/style.scss"],

        // Path and filename of your result bundle.
        // Webpack will bundle all JavaScript into this file
        output: {
            path: path.resolve(__dirname, "assets/dist"),
            filename: "js/min/ysp-child-theme.min.js",
            publicPath: "./assets/dist/"
        },
        module: {
            rules: [{
                    test: /\.js$/,
                    exclude: /(node_modules)/,
                    use: {
                        loader: "babel-loader",
                        options: {
                            presets: ["@babel/preset-env"]
                        }
                    }
                },
                {
                    // Apply rule for .sass, .scss or .css files
                    test: /\.(sa|sc|c)ss$/,
                    // Set loaders to transform files.
                    // Loaders are applying from right to left(!)
                    // The first loader will be applied after others
                    use: [{
                            // After all CSS loaders we use plugin to do his work.
                            // It gets all transformed CSS and extracts it into separate
                            // single bundled file
                            loader: MiniCssExtractPlugin.loader
                        },
                        {
                            // This loader resolves url() and @imports inside CSS
                            loader: "css-loader"
                        },
                        {
                            // Then we apply postCSS fixes like autoprefixer and minifying
                            loader: "postcss-loader"
                        },
                        {
                            // First we transform SASS to standard CSS
                            loader: "sass-loader",
                            options: {
                                implementation: require("sass")
                            }
                        }
                    ]
                },
                {
                    test: /\.(png|jpe?g|gif|svg)$/i,
                    use: [{
                        loader: "file-loader",
                        options: {
                            name: "[name].[ext]",
                            outputPath: "images"
                        }
                    }]
                }, {
                    test: /\.(woff(2)?|ttf|eot)(\?v=\d+\.\d+\.\d+)?$/,
                    use: [{
                        loader: "file-loader",
                        options: {
                            name: "[name].[ext]",
                            outputPath: "fonts"
                        }
                    }]
                }
            ]
        },
        plugins: [
            new MiniCssExtractPlugin({
                filename: "css/style.css"
            }),
            new FileManagerPlugin({
                onEnd: {
                    copy: [{
                        source: "./assets/dist/css/style.css",
                        destination: "./ysp-child-theme.css"
                    }]
                }
            }),
        ]
    },
    {
        name: "woocommerce",
        // Path to your entry point. From this file Webpack will begin his work
        entry: ["./assets/src/js/ysp-woocommerce.js", "./assets/src/scss/ysp-woocommerce.scss"],
        output: {
            path: path.resolve(__dirname, "assets/dist"),
            filename: "js/min/ysp-woocommerce.min.js",
            publicPath: "./assets/dist/"
        },
        module: {
            rules: [{
                    test: /\.js$/,
                    exclude: /(node_modules)/,
                    use: {
                        loader: "babel-loader",
                        options: {
                            presets: ["@babel/preset-env"]
                        }
                    }
                },
                {
                    // Apply rule for .sass, .scss or .css files
                    test: /\.(sa|sc|c)ss$/,
                    // Set loaders to transform files.
                    // Loaders are applying from right to left(!)
                    // The first loader will be applied after others
                    use: [{
                            // After all CSS loaders we use plugin to do his work.
                            // It gets all transformed CSS and extracts it into separate
                            // single bundled file
                            loader: MiniCssExtractPlugin.loader
                        },
                        {
                            // This loader resolves url() and @imports inside CSS
                            loader: "css-loader"
                        },
                        {
                            // Then we apply postCSS fixes like autoprefixer and minifying
                            loader: "postcss-loader"
                        },
                        {
                            // First we transform SASS to standard CSS
                            loader: "sass-loader",
                            options: {
                                implementation: require("sass")
                            }
                        }
                    ]
                }, {
                    test: /\.(png|jpe?g|gif|svg)$/i,
                    use: [{
                        loader: "file-loader",
                        options: {
                            name: "[name].[ext]",
                            outputPath: "images"
                        }
                    }]
                }, {
                    test: /\.(woff(2)?|ttf|eot)(\?v=\d+\.\d+\.\d+)?$/,
                    use: [{
                        loader: "file-loader",
                        options: {
                            name: "[name].[ext]",
                            outputPath: "fonts"
                        }
                    }]
                }
            ]
        },
        plugins: [
            new MiniCssExtractPlugin({
                filename: "css/ysp-woocommerce.min.css"
            }),
            new FileManagerPlugin({
                onEnd: {
                    copy: [{
                        source: './assets/dist/css/ysp-woocommerce.min.css',
                        destination: './ysp-woocommerce.min.css'
                    }]
                }
            }),
        ]
    }
];